function [ra, dec] = horizon2equator(alt, azi, lambda, phi, gast)

%HORIZON2EQUATOR - convert local alt. and azimuth to celestial coord.
%
%SYNOPSIS
% [RA, DEC] = horizon2equator(ALT, AZI, LAMBDA, PHI, GAST)
%
%INPUTS
%   ALT - altitude of a star (degrees)
%   AZI - azimuth of a star (degrees)
%          N.B. alt and azi are horizon coordinates  
%   LAMBDA - longitude of observer
%          N.B.  West of Greenwich , Lambda < 0
%                East of Greenwich, Lambda > 0     
%   PHI - latitude of observer
%   GAST - Greenwich apparent sidereal time(in hours)
%
%OUTPUTS
%   RA - Right ascension (in hours)
%   DEC - Declination (degrees)  
%
% Reference : pg 38 of Practical Astronomy With Your Calculator, 3rd
% edition Peter Duffet Smith
%
%AUTHOR
%   Shantani Desai (No longer part of the LV Collaboration)

% $Id: horizon2equator.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

A1 = sind(alt)*sind(phi) + cosd(alt)*cosd(phi)*cosd(azi) ;
dec = asind(A1);
A2 = (sind(alt) - sind(phi)*A1)/(cosd(phi)*cosd(dec)) ;
%lha = local Hour Angle in degrees
lha =  acosd(A2) ;

ra = gast - (lha - lambda)/15.0 ;

return
