function y = utc2gpsCorr(year, month, day, hour, min, sec)

%UTC2GPSCORR converts UTC time to GPS time with leap second correction
%
%SYNOPSIS
%   Y = utc2gpsCorr(YEAR, MONTH, DAY, HOUR, MIN, SEC)
% 
%INPUTS
%   YEAR - UTC year (4 digit)
%   MONTH - UTC month (1-2 digits)
%   DAY - UTC day (1-2 digits)
%   HOUR - UTC hour (1-2 digits)
%   MIN - UTC minute (1-2 digits)
%   SEC - UTC second (1-2 digits)
%
%OUTPUT
%  Y - GPS time in seconds
%
%AUTHOR
%   Shantanu Desai (No longer part of the LV Collaboration)

%  $Id: utc2gpsCorr.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% Error correction is not needed here since it is done in utc2gps.

% first calculate the GPS time without the correction
y = utc2gps(year, month, day, hour, min, sec);


% then apply the correction due to leap seconds
y = lsCorrAdd(y);

return
