function timeInSec = gps2time(gpsStruct)
%GPS2TIME Convert GPS(sec, ns) to double-prec time in seconds
%
%SYNOPSIS
%   TIMEINSEC = gps2time(GPSSTRUCT)
%
%INPUT
%   GPSSTRUCT   GPS time (struct with elements sec, ns)
%       sec whole seconds,
%       ns  residue in nano-seconds
%
%OUTPUT
%   TIMEINSEC   seconds + 10^-9 * nano-seconds
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: gps2time.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

%% Validation
%P IF # input arguments is wrong
%P   CREATE error
%P   EXIT
%P ENDIF
inErr = nargchk(1, 1, nargin);
if(~isempty(inErr))
    warning(inErr);
    error('timeInSec = gps2time(gpsStruct)');
end
%P IF # output arguments is wrong
%P   CREATE error
%P   EXIT
%P ENDIF
% outErr = nargchk(1, 1, nargout); % nargchk validates number of input
% arguments
% if(~isempty(outErr))
%     warning(outErr);
%     error('timeInSec = gps2time(gpsStruct)');
% end

%% Main program
%P CONVERT nano-seconds to seconds
%P  TIME = whole seconds + converted nano-seconds
secPerNsec = 0.000000001;
nanoInSec = secPerNsec * [gpsStruct(:).ns];
fullSec = [gpsStruct(:).sec];
timeInSec = fullSec + nanoInSec;

end
