function gps = ndx2gps(ndx,fs,gps0)
%NDX2GPS Convert indices to gps times
%
%SYNOPSIS
%   GPS = ndx2gps(NDX, FS, GPS0)
%
%INPUT
%   NDX     index or vector of indices
%   FS      sample rate
%   GPS0    gps time of first sample. Either a scalar or a struct with
%       elements sec, ns.
%
%OUTPUT
%   GPS     struct (array) gps time relative to time of first sample
%       sec: seconds
%       ns: nanoseconds
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: ndx2gps.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

sec = (ndx-1)/fs;
if (isstruct(gps0))
  sec = sec + gps0.sec + gps0.ns/1e9;
else
  sec = sec + gps0;
end

ns  = (sec - floor(sec))*1e9;
sec = floor(sec);
ns = floor(ns);
gps = struct('sec',num2cell(sec),'ns',num2cell(ns));

return
